@@ -1,5 +1,7 @@
-# Null-default operator
-`%||%` <- purrr::`%||%`
+# Empty-default operator
+`%||%` <- function(x, y) {
+  if (is.null(x) || length(x) == 0L) y else x
+}
 
 # Pipe operator
 `%>%` <- purrr::`%>%`
@@ -15,7 +17,12 @@ warning_wo_call <- function(...) warning(..., call. = FALSE)
 
 # Deparse a language object as a single string
 deparse_collapse <- function(x) {
-  paste(trimws(deparse(x), which = "both"), collapse = "")
+  d <- deparse(x)
+  if (length(d) > 1L) {
+    paste(trimws(gsub("\\s+", " ", d), which = "left"), collapse = "")
+  } else {
+    d
+  }
 }
 
 # Typically used to list symbols, such as function argument names
